@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 from django.test import TestCase
-from django.db import models
+from django.db import models, IntegrityError
 from decorators import opt_generator
 from parser import VkontakteParser
-from models import VkontaktePKModel, VkontakteManager
+from models import VkontakteIDModel, VkontaktePKModel, VkontakteManager
 from utils import api_call, VkontakteError
 import mock
 
@@ -11,14 +11,46 @@ class User(VkontaktePKModel):
     '''
     Test model should be on top level, otherwise table will not be created
     '''
-    screen_name = models.CharField(u'Короткое имя группы', max_length=50, db_index=True)
+    screen_name = models.CharField(u'Короткое имя группы', max_length=50, unique=True)
     slug_prefix = ''
 
     remote = VkontakteManager()
 
+class UserID(VkontakteIDModel):
+    screen_name = models.CharField(u'Короткое имя группы', max_length=50, unique=True)
+
 class VkontakteApiTest(TestCase):
 #    fixtures = ['oauth_tokens.usercredentials.json',]
 
+    def test_save_user_integrity_error(self):
+
+        user = UserID.objects.create(remote_id=1, screen_name='111')
+
+        # test absence of IntgrityError while creating
+        user_new = UserID.objects.create(remote_id=1, screen_name='222')
+        self.assertEqual(user_new.id, user.id)
+
+        # test absence of IntgrityError while saving
+        user_new = UserID(remote_id=1, screen_name='333')
+        user_new.save()
+        self.assertEqual(user_new.id, user.id)
+
+        # test IntgrityError by absence of remote_id
+        try:
+            user_new = UserID(screen_name='333')
+            user_new.save()
+            self.fail("IntegrityError didn't raised")
+        except IntegrityError:
+            pass
+
+        # test IntgrityError by screen_name
+        try:
+            user_new = UserID(remote_id=2, screen_name='333')
+            user_new.save()
+            self.fail("IntegrityError didn't raised")
+        except IntegrityError:
+            pass
+
     def test_parse_page(self):
 
         parser = VkontakteParser()
